@@ -11,7 +11,8 @@ LARGE_ORDERS = "/large-orders"
 POST_ORDER = "/order"
 CANCEL = "/order"
 ORDER_HISTORY = "/order-history"
+MARKET_ORDER_HISTORY = "/market-order-history"
 CANCEL_ALL = "/cancel-all"
 MID_POINT="/midpoint"
 PRICE = "/price"
-GET_LAST_TRADE_PRICE = "/last-trade-price";
\ No newline at end of file
+GET_LAST_TRADE_PRICE = "/last-trade-price"
\ No newline at end of file
